.. pynsitu documentation master file, created
   from xrft doc on 29/10/2022


pynsitu: Oceanographic In Situ Data analysis
==============================================

**pynsitu** is a Python package for the analysis of in situ oceanographic
data based on pandas_ and xarray_ objects.


.. note::

    some note about current status:
    This package is at early stage of development and will keep improving in the future.
    If you find any bugs or would like to request any enhancements,
    please `raise an issue on GitHub <https://github.com/apatlpo/pynsitu/issues>`_.

Documentation
-------------

.. toctree::
   :maxdepth: 1
   :caption: Getting Started

   why-pynsitu
   installation
   contributor_guide

.. toctree::
   :maxdepth: 1
   :caption: Examples

   example_events
   example_tseries
   example_tides
   example_drifters
   example_movie

.. toctree::
   :maxdepth: 1
   :caption: Help & reference

   whats-new
   api

.. _pandas: https://pandas.pydata.org
.. _xarray: http://xarray.pydata.org